@@ -193,10 +193,10 @@ func (w ValidatingWebhook) scanK8sFile(filePath string) (runtime.Output, error)
 
 	if flag.Lookup("test.v") != nil {
 		executor, err = runtime.NewExecutor("k8s", "v1", []string{"k8s"},
-			filePath, "", []string{testPoliciesPath}, []string{}, []string{}, []string{}, "")
+			filePath, "", []string{testPoliciesPath}, []string{}, []string{}, []string{}, "", false)
 	} else {
 		executor, err = runtime.NewExecutor("k8s", "v1", []string{"k8s"},
-			filePath, "", []string{}, []string{}, []string{}, []string{}, "")
+			filePath, "", []string{}, []string{}, []string{}, []string{}, "", false)
 	}
 	if err != nil {
 		zap.S().Errorf("failed to create runtime executer: '%v'", err)
@@ -231,10 +231,10 @@ func (w ValidatingWebhook) getDeniedViolations(violations results.ViolationStore
 
 	var denyViolations []results.Violation
 
-	denyRuleMatcher := webhookDenyRuleMatcher{}
+	denyRuleMatcher := WebhookDenyRuleMatcher{}
 
 	for _, violation := range violations.Violations {
-		if denyRuleMatcher.match(*violation, denyRules) {
+		if denyRuleMatcher.Match(*violation, denyRules) {
 			denyViolations = append(denyViolations, *violation)
 		}
 	}
@@ -326,11 +326,12 @@ func (w ValidatingWebhook) createResponseAdmissionReview(
 	return responseAdmissionReview
 }
 
-type webhookDenyRuleMatcher struct {
+// WebhookDenyRuleMatcher helps in matching violated rules with k8s denied admission control rules
+type WebhookDenyRuleMatcher struct {
 }
 
-// This class should check if one of the violations found is relevant for the specified K8s deny rules
-func (g *webhookDenyRuleMatcher) match(violation results.Violation, denyRules config.K8sAdmissionControl) bool {
+// Match should check if one of the violations found is relevant for the specified K8s deny rules
+func (g *WebhookDenyRuleMatcher) Match(violation results.Violation, denyRules config.K8sAdmissionControl) bool {
 
 	if denyRules.DeniedSeverity == "" && len(denyRules.Categories) == 0 {
 		return false
