@@ -23,9 +23,13 @@ import (
 	"testing"
 
 	iacProvider "github.com/accurics/terrascan/pkg/iac-providers"
+	helmv3 "github.com/accurics/terrascan/pkg/iac-providers/helm/v3"
+	k8sv1 "github.com/accurics/terrascan/pkg/iac-providers/kubernetes/v1"
+	kustomizev3 "github.com/accurics/terrascan/pkg/iac-providers/kustomize/v3"
 	tfv12 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v12"
 	tfv14 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v14"
 	"github.com/accurics/terrascan/pkg/notifications/webhook"
+	"github.com/hashicorp/go-multierror"
 
 	"github.com/accurics/terrascan/pkg/config"
 	"github.com/accurics/terrascan/pkg/iac-providers/output"
@@ -50,7 +54,7 @@ type MockIacProvider struct {
 	err    error
 }
 
-func (m MockIacProvider) LoadIacDir(dir string) (output.AllResourceConfigs, error) {
+func (m MockIacProvider) LoadIacDir(dir string, nonRecursive bool) (output.AllResourceConfigs, error) {
 	return m.output, m.err
 }
 
@@ -100,16 +104,16 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test LoadIacDir error",
 			executor: Executor{
-				dirPath:     "./testdata/testdir",
-				iacProvider: MockIacProvider{err: errMockLoadIacDir},
+				dirPath:      testDir,
+				iacProviders: []iacProvider.IacProvider{MockIacProvider{err: errMockLoadIacDir}},
 			},
-			wantErr: errMockLoadIacDir,
+			wantErr: multierror.Append(errMockLoadIacDir),
 		},
 		{
 			name: "test LoadIacDir no error",
 			executor: Executor{
-				dirPath:       "./testdata/testdir",
-				iacProvider:   MockIacProvider{err: nil},
+				dirPath:       testDir,
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: nil}},
 			},
 			wantErr: nil,
@@ -117,16 +121,17 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test LoadIacFile error",
 			executor: Executor{
-				filePath:    "./testdata/testfile",
-				iacProvider: MockIacProvider{err: errMockLoadIacFile},
+				filePath:     filepath.Join(testDataDir, "testfile"),
+				iacProviders: []iacProvider.IacProvider{MockIacProvider{err: errMockLoadIacFile}},
 			},
+			// iac file load doesn't return go-multierror
 			wantErr: errMockLoadIacFile,
 		},
 		{
 			name: "test LoadIacFile no error",
 			executor: Executor{
-				filePath:      "./testdata/testfile",
-				iacProvider:   MockIacProvider{err: nil},
+				filePath:      filepath.Join(testDataDir, "testfile"),
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: nil}},
 			},
 			wantErr: nil,
@@ -134,7 +139,7 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test SendNofitications no error",
 			executor: Executor{
-				iacProvider:   MockIacProvider{err: nil},
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				notifiers:     []notifications.Notifier{&MockNotifier{err: nil}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: nil}},
 			},
@@ -143,7 +148,7 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test SendNofitications mock error",
 			executor: Executor{
-				iacProvider:   MockIacProvider{err: nil},
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				notifiers:     []notifications.Notifier{&MockNotifier{err: errMockNotifier}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: nil}},
 			},
@@ -152,7 +157,7 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test policy enginer no error",
 			executor: Executor{
-				iacProvider:   MockIacProvider{err: nil},
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				notifiers:     []notifications.Notifier{&MockNotifier{err: nil}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: nil}},
 			},
@@ -161,7 +166,7 @@ func TestExecute(t *testing.T) {
 		{
 			name: "test policy engine error",
 			executor: Executor{
-				iacProvider:   MockIacProvider{err: nil},
+				iacProviders:  []iacProvider.IacProvider{MockIacProvider{err: nil}},
 				notifiers:     []notifications.Notifier{&MockNotifier{err: nil}},
 				policyEngines: []policy.Engine{MockPolicyEngine{err: errMockPolicyEngine}},
 			},
@@ -185,7 +190,7 @@ func TestInit(t *testing.T) {
 		executor        Executor
 		wantErr         error
 		configFile      string
-		wantIacProvider iacProvider.IacProvider
+		wantIacProvider []iacProvider.IacProvider
 		wantNotifiers   []notifications.Notifier
 	}{
 		{
@@ -199,7 +204,29 @@ func TestInit(t *testing.T) {
 				policyPath: []string{testPoliciesDir},
 			},
 			wantErr:         nil,
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
+			wantNotifiers:   []notifications.Notifier{},
+		},
+		{
+			name: "empty iac type with -d flag",
+			executor: Executor{
+				dirPath:    testDataDir,
+				cloudType:  []string{"aws"},
+				policyPath: []string{testPoliciesDir},
+			},
+			wantErr:         nil,
+			wantIacProvider: []iacProvider.IacProvider{&helmv3.HelmV3{}, &k8sv1.K8sV1{}, &kustomizev3.KustomizeV3{}, &tfv14.TfV14{}},
+			wantNotifiers:   []notifications.Notifier{},
+		},
+		{
+			name: "empty iac type with -f flag",
+			executor: Executor{
+				filePath:   filepath.Join(testDataDir, "testfile"),
+				cloudType:  []string{"aws"},
+				policyPath: []string{testPoliciesDir},
+			},
+			wantErr:         nil,
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 			wantNotifiers:   []notifications.Notifier{},
 		},
 		{
@@ -214,7 +241,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "webhook.toml"),
 			wantErr:         nil,
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 		{
@@ -228,7 +255,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "invalid-notifier.toml"),
 			wantErr:         fmt.Errorf("notifier not supported"),
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 		{
@@ -242,7 +269,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "does-not-exist"),
 			wantErr:         config.ErrNotPresent,
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 		},
 		{
 			name: "invalid policy path",
@@ -256,7 +283,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "webhook.toml"),
 			wantErr:         fmt.Errorf("failed to initialize OPA policy engine"),
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 		{
@@ -271,7 +298,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "invalid-category.toml"),
 			wantErr:         fmt.Errorf("(3, 5): no value can start with c"),
-			wantIacProvider: &tfv14.TfV14{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv14.TfV14{}},
 		},
 		{
 			name: "valid filePath",
@@ -284,7 +311,7 @@ func TestInit(t *testing.T) {
 				policyPath: []string{testPoliciesDir},
 			},
 			wantErr:         nil,
-			wantIacProvider: &tfv12.TfV12{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 			wantNotifiers:   []notifications.Notifier{},
 		},
 		{
@@ -299,7 +326,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "webhook.toml"),
 			wantErr:         nil,
-			wantIacProvider: &tfv12.TfV12{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 		{
@@ -313,7 +340,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "invalid-notifier.toml"),
 			wantErr:         fmt.Errorf("notifier not supported"),
-			wantIacProvider: &tfv12.TfV12{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 		{
@@ -327,7 +354,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "does-not-exist"),
 			wantErr:         config.ErrNotPresent,
-			wantIacProvider: &tfv12.TfV12{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 		},
 		{
 			name: "invalid policy path",
@@ -341,7 +368,7 @@ func TestInit(t *testing.T) {
 			},
 			configFile:      filepath.Join(testDataDir, "webhook.toml"),
 			wantErr:         fmt.Errorf("failed to initialize OPA policy engine"),
-			wantIacProvider: &tfv12.TfV12{},
+			wantIacProvider: []iacProvider.IacProvider{&tfv12.TfV12{}},
 			wantNotifiers:   []notifications.Notifier{&webhook.Webhook{}},
 		},
 	}
@@ -359,8 +386,8 @@ func TestInit(t *testing.T) {
 				if !reflect.DeepEqual(gotErr, tt.wantErr) {
 					t.Errorf("unexpected error; gotErr: '%v', wantErr: '%v'", gotErr, tt.wantErr)
 				}
-				if !reflect.DeepEqual(tt.executor.iacProvider, tt.wantIacProvider) {
-					t.Errorf("got: '%v', want: '%v'", tt.executor.iacProvider, tt.wantIacProvider)
+				if !reflect.DeepEqual(tt.executor.iacProviders, tt.wantIacProvider) {
+					t.Errorf("got: '%v', want: '%v'", tt.executor.iacProviders, tt.wantIacProvider)
 				}
 				if len(tt.wantNotifiers) > 0 {
 					for i, notifier := range tt.executor.notifiers {
@@ -513,7 +540,7 @@ func TestNewExecutor(t *testing.T) {
 		t.Run(tt.name, func(t *testing.T) {
 			config.LoadGlobalConfig(tt.configfile)
 
-			gotExecutor, gotErr := NewExecutor(tt.flags.iacType, tt.flags.iacVersion, tt.flags.cloudType, tt.flags.filePath, tt.flags.dirPath, tt.flags.policyPath, tt.flags.scanRules, tt.flags.skipRules, tt.flags.categories, tt.flags.severity)
+			gotExecutor, gotErr := NewExecutor(tt.flags.iacType, tt.flags.iacVersion, tt.flags.cloudType, tt.flags.filePath, tt.flags.dirPath, tt.flags.policyPath, tt.flags.scanRules, tt.flags.skipRules, tt.flags.categories, tt.flags.severity, false)
 
 			if !reflect.DeepEqual(tt.wantErr, gotErr) {
 				t.Errorf("Mismatch in error => got: '%v', want: '%v'", gotErr, tt.wantErr)
